package sun.security.krb5.internal.rcache;

import java.util.Objects;

public class AuthTimeWithHash extends AuthTime implements Comparable<AuthTimeWithHash>
{
    final String hash;
    
    public AuthTimeWithHash(String s, String s2, int n, int n2, String hash) {
        super(s, s2, n, n2);
        this.hash = hash;
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof AuthTimeWithHash)) {
            return false;
        }
        AuthTimeWithHash authTimeWithHash = (AuthTimeWithHash)o;
        return Objects.equals(this.hash, authTimeWithHash.hash) && Objects.equals(this.client, authTimeWithHash.client) && Objects.equals(this.server, authTimeWithHash.server) && this.ctime == authTimeWithHash.ctime && this.cusec == authTimeWithHash.cusec;
    }
    
    @Override
    public int hashCode() {
        return Objects.hash(new Object[] { this.hash });
    }
    
    @Override
    public String toString() {
        return String.format("%d/%06d/%s/%s", new Object[] { Integer.valueOf(this.ctime), Integer.valueOf(this.cusec), this.hash, this.client });
    }
    
    @Override
    public int compareTo(AuthTimeWithHash authTimeWithHash) {
        int n;
        if (this.ctime != authTimeWithHash.ctime) {
            n = Integer.compare(this.ctime, authTimeWithHash.ctime);
        }
        else if (this.cusec != authTimeWithHash.cusec) {
            n = Integer.compare(this.cusec, authTimeWithHash.cusec);
        }
        else {
            n = this.hash.compareTo(authTimeWithHash.hash);
        }
        return n;
    }
    
    public boolean isSameIgnoresHash(AuthTime authTime) {
        return this.client.equals(authTime.client) && this.server.equals(authTime.server) && this.ctime == authTime.ctime && this.cusec == authTime.cusec;
    }
    
    @Override
    public byte[] encode(boolean b) {
        String client;
        String s;
        if (b) {
            client = "";
            s = String.format("HASH:%s %d:%s %d:%s", new Object[] { this.hash, Integer.valueOf(this.client.length()), this.client, Integer.valueOf(this.server.length()), this.server });
        }
        else {
            client = this.client;
            s = this.server;
        }
        return this.encode0(client, s);
    }
}
